import codecommit = require('@aws-cdk/aws-codecommit');
import s3 = require('@aws-cdk/aws-s3');
/**
 * Properties common to all Source classes.
 */
export interface BuildSourceProps {
    /**
     * The source identifier.
     * This property is required on secondary sources.
     */
    readonly identifier?: string;
}
/**
 * Source provider definition for a CodeBuild Project.
 */
export declare abstract class BuildSource {
    readonly identifier?: string;
    abstract readonly type: SourceType;
    readonly badgeSupported: boolean;
    constructor(props: BuildSourceProps);
    protected toSourceProperty(): any;
}
/**
 * A `NO_SOURCE` CodeBuild Project Source definition.
 * This is the default source type,
 * if none was specified when creating the Project.
 * *Note*: the `NO_SOURCE` type cannot be used as a secondary source,
 * and because of that, you're not allowed to specify an identifier for it.
 */
export declare class NoSource extends BuildSource {
    readonly type: SourceType;
    constructor();
}
/**
 * The construction properties common to all build sources that are backed by Git.
 */
export interface GitBuildSourceProps extends BuildSourceProps {
    /**
     * The depth of history to download. Minimum value is 0.
     * If this value is 0, greater than 25, or not provided,
     * then the full history is downloaded with each build of the project.
     */
    readonly cloneDepth?: number;
}
/**
 * A common superclass of all build sources that are backed by Git.
 */
export declare abstract class GitBuildSource extends BuildSource {
    private readonly cloneDepth?;
    protected constructor(props: GitBuildSourceProps);
}
/**
 * The types of webhook event actions.
 */
export declare enum EventAction {
    /**
     * A push (of a branch, or a tag) to the repository.
     */
    PUSH = "PUSH",
    /**
     * Creating a Pull Request.
     */
    PULL_REQUEST_CREATED = "PULL_REQUEST_CREATED",
    /**
     * Updating an Pull Request.
     */
    PULL_REQUEST_UPDATED = "PULL_REQUEST_UPDATED",
    /**
     * Re-opening a previously closed Pull Request.
     * Note that this event is only supported for GitHub and GitHubEnterprise sources.
     */
    PULL_REQUEST_REOPENED = "PULL_REQUEST_REOPENED"
}
/**
 * An object that represents a group of filter conditions for a webhook.
 * Every condition in a given FilterGroup must be true in order for the whole group to be true.
 * You construct instances of it by calling the {@link #inEventOf} static factory method,
 * and then calling various `andXyz` instance methods to create modified instances of it
 * (this class is immutable).
 *
 * You pass instances of this class to the `webhookFilters` property when constructing a source.
 */
export declare class FilterGroup {
    /**
     * Creates a new event FilterGroup that triggers on any of the provided actions.
     *
     * @param actions the actions to trigger the webhook on
     */
    static inEventOf(...actions: EventAction[]): FilterGroup;
    private readonly actions;
    private readonly filters;
    private constructor();
    /**
     * Create a new FilterGroup with an added condition:
     * the event must affect the given branch.
     *
     * @param branchName the name of the branch (can be a regular expression)
     */
    andBranchIs(branchName: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the event must not affect the given branch.
     *
     * @param branchName the name of the branch (can be a regular expression)
     */
    andBranchIsNot(branchName: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the event must affect the given tag.
     *
     * @param tagName the name of the tag (can be a regular expression)
     */
    andTagIs(tagName: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the event must not affect the given tag.
     *
     * @param tagName the name of the tag (can be a regular expression)
     */
    andTagIsNot(tagName: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the event must affect a Git reference (ie., a branch or a tag)
     * that matches the given pattern.
     *
     * @param pattern a regular expression
     */
    andHeadRefIs(pattern: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the event must not affect a Git reference (ie., a branch or a tag)
     * that matches the given pattern.
     *
     * @param pattern a regular expression
     */
    andHeadRefIsNot(pattern: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the account ID of the actor initiating the event must match the given pattern.
     *
     * @param pattern a regular expression
     */
    andActorAccountIs(pattern: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the account ID of the actor initiating the event must not match the given pattern.
     *
     * @param pattern a regular expression
     */
    andActorAccountIsNot(pattern: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the Pull Request that is the source of the event must target the given base branch.
     * Note that you cannot use this method if this Group contains the `PUSH` event action.
     *
     * @param branchName the name of the branch (can be a regular expression)
     */
    andBaseBranchIs(branchName: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the Pull Request that is the source of the event must not target the given base branch.
     * Note that you cannot use this method if this Group contains the `PUSH` event action.
     *
     * @param branchName the name of the branch (can be a regular expression)
     */
    andBaseBranchIsNot(branchName: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the Pull Request that is the source of the event must target the given Git reference.
     * Note that you cannot use this method if this Group contains the `PUSH` event action.
     *
     * @param pattern a regular expression
     */
    andBaseRefIs(pattern: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the Pull Request that is the source of the event must not target the given Git reference.
     * Note that you cannot use this method if this Group contains the `PUSH` event action.
     *
     * @param pattern a regular expression
     */
    andBaseRefIsNot(pattern: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the push that is the source of the event must affect a file that matches the given pattern.
     * Note that you can only use this method if this Group contains only the `PUSH` event action,
     * and only for GitHub and GitHubEnterprise sources.
     *
     * @param pattern a regular expression
     */
    andFilePathIs(pattern: string): FilterGroup;
    /**
     * Create a new FilterGroup with an added condition:
     * the push that is the source of the event must not affect a file that matches the given pattern.
     * Note that you can only use this method if this Group contains only the `PUSH` event action,
     * and only for GitHub and GitHubEnterprise sources.
     *
     * @param pattern a regular expression
     */
    andFilePathIsNot(pattern: string): FilterGroup;
    private addHeadBranchFilter;
    private addHeadTagFilter;
    private addHeadRefFilter;
    private addActorAccountId;
    private addBaseBranchFilter;
    private addBaseRefFilter;
    private addFilePathFilter;
    private addFilter;
}
/**
 * The construction properties common to all third-party build sources that are backed by Git.
 */
export interface ThirdPartyGitBuildSourceProps extends GitBuildSourceProps {
    /**
     * Whether to send notifications on your build's start and end.
     *
     * @default true
     */
    readonly reportBuildStatus?: boolean;
    /**
     * Whether to create a webhook that will trigger a build every time an event happens in the repository.
     *
     * @default true if any `webhookFilters` were provided, false otherwise
     */
    readonly webhook?: boolean;
    /**
     * A list of webhook filters that can constraint what events in the repository will trigger a build.
     * A build is triggered if any of the provided filter groups match.
     * Only valid if `webhook` was not provided as false.
     *
     * @default every push and every Pull Request (create or update) triggers a build
     */
    readonly webhookFilters?: FilterGroup[];
}
/**
 * A common superclass of all third-party build sources that are backed by Git.
 */
export declare abstract class ThirdPartyGitBuildSource extends GitBuildSource {
    readonly badgeSupported: boolean;
    protected readonly webhookFilters: FilterGroup[];
    private readonly reportBuildStatus;
    private readonly webhook?;
    protected constructor(props: ThirdPartyGitBuildSourceProps);
}
/**
 * Construction properties for {@link CodeCommitSource}.
 */
export interface CodeCommitSourceProps extends GitBuildSourceProps {
    readonly repository: codecommit.IRepository;
}
/**
 * CodeCommit Source definition for a CodeBuild project.
 */
export declare class CodeCommitSource extends GitBuildSource {
    readonly type: SourceType;
    private readonly repo;
    constructor(props: CodeCommitSourceProps);
    protected toSourceProperty(): any;
}
/**
 * Construction properties for {@link S3BucketSource}.
 */
export interface S3BucketSourceProps extends BuildSourceProps {
    readonly bucket: s3.IBucket;
    readonly path: string;
}
/**
 * S3 bucket definition for a CodeBuild project.
 */
export declare class S3BucketSource extends BuildSource {
    readonly type: SourceType;
    private readonly bucket;
    private readonly path;
    constructor(props: S3BucketSourceProps);
    protected toSourceProperty(): any;
}
/**
 * CodePipeline Source definition for a CodeBuild Project.
 * *Note*: this type cannot be used as a secondary source,
 * and because of that, you're not allowed to specify an identifier for it.
 */
export declare class CodePipelineSource extends BuildSource {
    readonly type: SourceType;
    constructor();
}
/**
 * Construction properties for {@link GitHubSource} and {@link GitHubEnterpriseSource}.
 */
export interface GitHubSourceProps extends ThirdPartyGitBuildSourceProps {
    /**
     * The GitHub account/user that owns the repo.
     *
     * @example 'awslabs'
     */
    readonly owner: string;
    /**
     * The name of the repo (without the username).
     *
     * @example 'aws-cdk'
     */
    readonly repo: string;
}
/**
 * GitHub Source definition for a CodeBuild project.
 */
export declare class GitHubSource extends ThirdPartyGitBuildSource {
    readonly type: SourceType;
    private readonly httpsCloneUrl;
    constructor(props: GitHubSourceProps);
    protected toSourceProperty(): any;
}
/**
 * Construction properties for {@link GitHubEnterpriseSource}.
 */
export interface GitHubEnterpriseSourceProps extends ThirdPartyGitBuildSourceProps {
    /**
     * The HTTPS URL of the repository in your GitHub Enterprise installation.
     */
    readonly httpsCloneUrl: string;
    /**
     * Whether to ignore SSL errors when connecting to the repository.
     *
     * @default false
     */
    readonly ignoreSslErrors?: boolean;
}
/**
 * GitHub Enterprise Source definition for a CodeBuild project.
 */
export declare class GitHubEnterpriseSource extends ThirdPartyGitBuildSource {
    readonly type: SourceType;
    private readonly httpsCloneUrl;
    private readonly ignoreSslErrors?;
    constructor(props: GitHubEnterpriseSourceProps);
    protected toSourceProperty(): any;
}
/**
 * Construction properties for {@link BitBucketSource}.
 */
export interface BitBucketSourceProps extends ThirdPartyGitBuildSourceProps {
    /**
     * The BitBucket account/user that owns the repo.
     *
     * @example 'awslabs'
     */
    readonly owner: string;
    /**
     * The name of the repo (without the username).
     *
     * @example 'aws-cdk'
     */
    readonly repo: string;
}
/**
 * BitBucket Source definition for a CodeBuild project.
 */
export declare class BitBucketSource extends ThirdPartyGitBuildSource {
    readonly type: SourceType;
    private readonly httpsCloneUrl;
    constructor(props: BitBucketSourceProps);
    protected toSourceProperty(): any;
    private anyWebhookFilterContainsPrReopenedEventAction;
    private anyWebhookFilterContainsFilePathConditions;
}
/**
 * Source types for CodeBuild Project
 */
export declare enum SourceType {
    None = "NO_SOURCE",
    CodeCommit = "CODECOMMIT",
    CodePipeline = "CODEPIPELINE",
    GitHub = "GITHUB",
    GitHubEnterprise = "GITHUB_ENTERPRISE",
    BitBucket = "BITBUCKET",
    S3 = "S3"
}
